@@ -6,6 +6,7 @@
 #' @param var1 The name (as a string) of the variable of interest in the interaction term; its conditional coefficient estimates will be plotted.
 #' @param var2 The name (as a string) of the other variable in the interaction term.
 #' @param plot A logical value indicating whether the output is a plot or a dataframe including the conditional coefficient estimates of var1, their upper and lower bounds, and the corresponding values of var2.
+#' @param steps Desired length of the sequence. A non-negative number, which for seq and seq.int will be rounded up if fractional. The default is 100 or the unique categories in the \code{var2} (when it is less than 100. Also see \code{\link{unique}}).
 #' @param hist A logical value indicating if there is a histogram of `var2` added at the bottom of the conditional effect plot.
 #' @param var2_dt A numerical value indicating the frequency distibution of `var2`. It is only used when `hist == TRUE`. When the object is a model, the default is the distribution of `var2` of the model. 
 #' @param point A logical value determining the format of plot. By default, the function produces a line plot when var2 takes on ten or more distinct values and a point (dot-and-whisker) plot otherwise; option TRUE forces a point plot.
@@ -37,8 +38,9 @@
 #' @export
 
 # S3 method for class 'lm' and 'glm'
-interplot.default <- function(m, var1, var2, plot = TRUE, hist = FALSE, var2_dt = NA, point = FALSE, 
-    sims = 5000, xmin = NA, xmax = NA, ercolor = NA, esize = 0.5, ralpha = 0.5, rfill = "grey70", 
+interplot.default <- function(m, var1, var2, plot = TRUE, steps = NULL, 
+    hist = FALSE, var2_dt = NA, point = FALSE, sims = 5000, xmin = NA, 
+    xmax = NA, ercolor = NA, esize = 0.5, ralpha = 0.5, rfill = "grey70", 
     ...) {
     set.seed(324)
     
@@ -58,39 +60,45 @@ interplot.default <- function(m, var1, var2, plot = TRUE, hist = FALSE, var2_dt
         var1_bk <- var1
         var1 <- paste0(var1, eval(parse(text = paste0("m$xlevel$", var1))))
         factor_v1 <- TRUE
-        ifelse(var1 == var2, var12 <- paste0("I(", var1, "^2)"), var12 <- paste0(var2, ":", var1)[-1])
+        ifelse(var1 == var2, var12 <- paste0("I(", var1, "^2)"), var12 <- paste0(var2, 
+            ":", var1)[-1])
         
         # the first category is censored to avoid multicolinarity
         for (i in seq(var12)) {
             if (!var12[i] %in% names(m$coef)) 
                 var12[i] <- paste0(var1, ":", var2)[-1][i]
             if (!var12[i] %in% names(m$coef)) 
-                stop(paste("Model does not include the interaction of", var1, "and", var2, "."))
+                stop(paste("Model does not include the interaction of", 
+                  var1, "and", var2, "."))
         }
         
     } else if (is.factor(eval(parse(text = paste0("m$model$", var2))))) {
         var2_bk <- var2
         var2 <- paste0(var2, eval(parse(text = paste0("m$xlevel$", var2))))
         factor_v2 <- TRUE
-        ifelse(var1 == var2, var12 <- paste0("I(", var1, "^2)"), var12 <- paste0(var2, ":", var1)[-1])
+        ifelse(var1 == var2, var12 <- paste0("I(", var1, "^2)"), var12 <- paste0(var2, 
+            ":", var1)[-1])
         
         # the first category is censored to avoid multicolinarity
         for (i in seq(var12)) {
             if (!var12[i] %in% names(m$coef)) 
                 var12[i] <- paste0(var1, ":", var2)[-1][i]
             if (!var12[i] %in% names(m$coef)) 
-                stop(paste("Model does not include the interaction of", var1, "and", var2, "."))
+                stop(paste("Model does not include the interaction of", 
+                  var1, "and", var2, "."))
         }
         
     } else {
-        ifelse(var1 == var2, var12 <- paste0("I(", var1, "^2)"), var12 <- paste0(var2, ":", var1))
+        ifelse(var1 == var2, var12 <- paste0("I(", var1, "^2)"), var12 <- paste0(var2, 
+            ":", var1))
         
         # the first category is censored to avoid multicolinarity
         for (i in seq(var12)) {
             if (!var12[i] %in% names(m$coef)) 
                 var12[i] <- paste0(var1, ":", var2)[i]
             if (!var12[i] %in% names(m$coef)) 
-                stop(paste("Model does not include the interaction of", var1, "and", var2, "."))
+                stop(paste("Model does not include the interaction of", 
+                  var1, "and", var2, "."))
         }
     }
     
@@ -107,26 +115,37 @@ interplot.default <- function(m, var1, var2, plot = TRUE, hist = FALSE, var2_dt
         if (is.na(xmax)) 
             xmax <- max(m$model[var2], na.rm = T)
         
-        steps <- eval(parse(text = paste0("length(unique(na.omit(m$model$", var2, ")))")))
+        if (is.null(steps)) {
+            steps <- eval(parse(text = paste0("length(unique(na.omit(m$model$", 
+                var2, ")))")))
+        }
+        
+        
         if (steps > 100) 
             steps <- 100  # avoid redundant calculation
     }
     
-    coef <- data.frame(fake = seq(xmin, xmax, length.out = steps), coef1 = NA, ub = NA, lb = NA)
-    coef_df <- data.frame(fake = numeric(0), coef1 = numeric(0), ub = numeric(0), lb = numeric(0), 
-        model = character(0))
+    coef <- data.frame(fake = seq(xmin, xmax, length.out = steps), coef1 = NA, 
+        ub = NA, lb = NA)
+    coef_df <- data.frame(fake = numeric(0), coef1 = numeric(0), ub = numeric(0), 
+        lb = numeric(0), model = character(0))
     
     if (factor_v1) {
-        for (j in 1:(length(eval(parse(text = paste0("m$xlevel$", var1_bk)))) - 1)) {
-            # only n - 1 interactions; one category is avoided against multicolinarity
+        for (j in 1:(length(eval(parse(text = paste0("m$xlevel$", var1_bk)))) - 
+            1)) {
+            # only n - 1 interactions; one category is avoided against
+            # multicolinarity
             
             for (i in 1:steps) {
-                coef$coef1[i] <- mean(m.sims@coef[, match(var1[j + 1], names(m$coef))] + coef$fake[i] * 
-                  m.sims@coef[, match(var12[j], names(m$coef))])
-                coef$ub[i] <- quantile(m.sims@coef[, match(var1[j + 1], names(m$coef))] + coef$fake[i] * 
-                  m.sims@coef[, match(var12[j], names(m$coef))], 0.975)
-                coef$lb[i] <- quantile(m.sims@coef[, match(var1[j + 1], names(m$coef))] + coef$fake[i] * 
-                  m.sims@coef[, match(var12[j], names(m$coef))], 0.025)
+                coef$coef1[i] <- mean(m.sims@coef[, match(var1[j + 1], 
+                  names(m$coef))] + coef$fake[i] * m.sims@coef[, match(var12[j], 
+                  names(m$coef))])
+                coef$ub[i] <- quantile(m.sims@coef[, match(var1[j + 1], 
+                  names(m$coef))] + coef$fake[i] * m.sims@coef[, match(var12[j], 
+                  names(m$coef))], 0.975)
+                coef$lb[i] <- quantile(m.sims@coef[, match(var1[j + 1], 
+                  names(m$coef))] + coef$fake[i] * m.sims@coef[, match(var12[j], 
+                  names(m$coef))], 0.025)
             }
             
             if (plot == TRUE) {
@@ -145,19 +164,25 @@ interplot.default <- function(m, var1, var2, plot = TRUE, hist = FALSE, var2_dt
             }
         }
         coef_df$value <- as.factor(coef_df$value)
-        interplot.plot(m = coef_df, hist = hist, var2_dt = var2_dt, point = point, ercolor = ercolor, esize = esize, ralpha = ralpha, rfill = rfill, ...) + facet_grid(. ~ value)
+        interplot.plot(m = coef_df, hist = hist, var2_dt = var2_dt, steps = steps, 
+            point = point, ercolor = ercolor, esize = esize, ralpha = ralpha, 
+            rfill = rfill, ...) + facet_grid(. ~ value)
         
     } else if (factor_v2) {
-        for (j in 1:(length(eval(parse(text = paste0("m$xlevel$", var2_bk)))) - 1)) {
-            # only n - 1 interactions; one category is avoided against multicolinarity
+        for (j in 1:(length(eval(parse(text = paste0("m$xlevel$", var2_bk)))) - 
+            1)) {
+            # only n - 1 interactions; one category is avoided against
+            # multicolinarity
             
             for (i in 1:steps) {
-                coef$coef1[i] <- mean(m.sims@coef[, match(var1, names(m$coef))] + coef$fake[i] * 
-                  m.sims@coef[, match(var12[j], names(m$coef))])
-                coef$ub[i] <- quantile(m.sims@coef[, match(var1, names(m$coef))] + coef$fake[i] * 
-                  m.sims@coef[, match(var12[j], names(m$coef))], 0.975)
-                coef$lb[i] <- quantile(m.sims@coef[, match(var1, names(m$coef))] + coef$fake[i] * 
-                  m.sims@coef[, match(var12[j], names(m$coef))], 0.025)
+                coef$coef1[i] <- mean(m.sims@coef[, match(var1, names(m$coef))] + 
+                  coef$fake[i] * m.sims@coef[, match(var12[j], names(m$coef))])
+                coef$ub[i] <- quantile(m.sims@coef[, match(var1, names(m$coef))] + 
+                  coef$fake[i] * m.sims@coef[, match(var12[j], names(m$coef))], 
+                  0.975)
+                coef$lb[i] <- quantile(m.sims@coef[, match(var1, names(m$coef))] + 
+                  coef$fake[i] * m.sims@coef[, match(var12[j], names(m$coef))], 
+                  0.025)
             }
             
             if (plot == TRUE) {
@@ -176,8 +201,9 @@ interplot.default <- function(m, var1, var2, plot = TRUE, hist = FALSE, var2_dt
             }
         }
         coef_df$value <- as.factor(coef_df$value)
-        interplot.plot(m = coef_df, hist = hist, var2_dt = var2_dt, point = point, ercolor = ercolor, 
-            esize = esize, ralpha = ralpha, rfill = rfill, ...) + facet_grid(. ~ value)
+        interplot.plot(m = coef_df, hist = hist, steps = steps, var2_dt = var2_dt, 
+            point = point, ercolor = ercolor, esize = esize, ralpha = ralpha, 
+            rfill = rfill, ...) + facet_grid(. ~ value)
         
         
     } else {
@@ -186,12 +212,15 @@ interplot.default <- function(m, var1, var2, plot = TRUE, hist = FALSE, var2_dt
             2 else 1
         
         for (i in 1:steps) {
-            coef$coef1[i] <- mean(m.sims@coef[, match(var1, names(m$coef))] + multiplier * coef$fake[i] * 
-                m.sims@coef[, match(var12, names(m$coef))])
-            coef$ub[i] <- quantile(m.sims@coef[, match(var1, names(m$coef))] + multiplier * coef$fake[i] * 
-                m.sims@coef[, match(var12, names(m$coef))], 0.975)
-            coef$lb[i] <- quantile(m.sims@coef[, match(var1, names(m$coef))] + multiplier * coef$fake[i] * 
-                m.sims@coef[, match(var12, names(m$coef))], 0.025)
+            coef$coef1[i] <- mean(m.sims@coef[, match(var1, names(m$coef))] + 
+                multiplier * coef$fake[i] * m.sims@coef[, match(var12, 
+                  names(m$coef))])
+            coef$ub[i] <- quantile(m.sims@coef[, match(var1, names(m$coef))] + 
+                multiplier * coef$fake[i] * m.sims@coef[, match(var12, 
+                  names(m$coef))], 0.975)
+            coef$lb[i] <- quantile(m.sims@coef[, match(var1, names(m$coef))] + 
+                multiplier * coef$fake[i] * m.sims@coef[, match(var12, 
+                  names(m$coef))], 0.025)
         }
         
         if (plot == TRUE) {
@@ -202,8 +231,9 @@ interplot.default <- function(m, var1, var2, plot = TRUE, hist = FALSE, var2_dt
                   var2_dt <- var2_dt
                 }
             }
-            interplot.plot(m = coef, hist = hist, var2_dt = var2_dt, point = point, ercolor = ercolor, 
-                esize = esize, ralpha = ralpha, rfill = rfill, ...)
+            interplot.plot(m = coef, steps = steps, hist = hist, var2_dt = var2_dt, 
+                point = point, ercolor = ercolor, esize = esize, ralpha = ralpha, 
+                rfill = rfill, ...)
         } else {
             names(coef) <- c(var2, "coef", "ub", "lb")
             return(coef)
@@ -211,4 +241,4 @@ interplot.default <- function(m, var1, var2, plot = TRUE, hist = FALSE, var2_dt
         
     }
     
-} 
+}
