@@ -6,6 +6,7 @@
 #' @param var1 The name (as a string) of the variable of interest in the interaction term; its conditional coefficient estimates will be plotted.
 #' @param var2 The name (as a string) of the other variable in the interaction term.
 #' @param plot A logical value indicating whether the output is a plot or a dataframe including the conditional coefficient estimates of var1, their upper and lower bounds, and the corresponding values of var2.
+#' @param steps Desired length of the sequence. A non-negative number, which for seq and seq.int will be rounded up if fractional. The default is 100 or the unique categories in the \code{var2} (when it is less than 100. Also see \code{\link{unique}}).
 #' @param hist A logical value indicating if there is a histogram of `var2` added at the bottom of the conditional effect plot.
 #' @param var2_dt A numerical value indicating the frequency distibution of `var2`. It is only used when `hist == TRUE`. When the object is a model, the default is the distribution of `var2` of the model. 
 #' @param point A logical value determining the format of plot. By default, the function produces a line plot when var2 takes on ten or more distinct values and a point (dot-and-whisker) plot otherwise; option TRUE forces a point plot.
@@ -33,8 +34,9 @@
 #' @export
 
 # Coding function for non-mi mlm objects
-interplot.lmerMod <- function(m, var1, var2, plot = TRUE, hist = FALSE, var2_dt = NA, point = FALSE, sims = 5000, xmin = NA, 
-    xmax = NA, ercolor = NA, esize = 0.5, ralpha = 0.5, rfill = "grey70", ...) {
+interplot.lmerMod <- function(m, var1, var2, plot = TRUE, steps = NULL, hist = FALSE, 
+    var2_dt = NA, point = FALSE, sims = 5000, xmin = NA, xmax = NA, ercolor = NA, 
+    esize = 0.5, ralpha = 0.5, rfill = "grey70", ...) {
     set.seed(324)
     
     m.class <- class(m)
@@ -49,39 +51,47 @@ interplot.lmerMod <- function(m, var1, var2, plot = TRUE, hist = FALSE, var2_dt
     
     if (is.factor(eval(parse(text = paste0("m@frame$", var1))))) {
         var1_bk <- var1
-        var1 <- paste0(var1, levels(eval(parse(text = paste0("m@frame$", var1)))))
+        var1 <- paste0(var1, levels(eval(parse(text = paste0("m@frame$", 
+            var1)))))
         factor_v1 <- TRUE
-        ifelse(var1 == var2, var12 <- paste0("I(", var1, "^2)"), var12 <- paste0(var2, ":", var1)[-1])
+        ifelse(var1 == var2, var12 <- paste0("I(", var1, "^2)"), var12 <- paste0(var2, 
+            ":", var1)[-1])
         
         # the first category is censored to avoid multicolinarity
         for (i in seq(var12)) {
             if (!var12[i] %in% unlist(dimnames(m@pp$X)[2])) 
                 var12[i] <- paste0(var1, ":", var2)[-1][i]
             if (!var12[i] %in% unlist(dimnames(m@pp$X)[2])) 
-                stop(paste("Model does not include the interaction of", var1, "and", var2, "."))
+                stop(paste("Model does not include the interaction of", 
+                  var1, "and", var2, "."))
         }
     } else if (is.factor(eval(parse(text = paste0("m@frame$", var2))))) {
         var2_bk <- var2
-        var2 <- paste0(var2, levels(eval(parse(text = paste0("m@frame$", var2)))))
+        var2 <- paste0(var2, levels(eval(parse(text = paste0("m@frame$", 
+            var2)))))
         factor_v2 <- TRUE
-        ifelse(var1 == var2, var12 <- paste0("I(", var1, "^2)"), var12 <- paste0(var2, ":", var1)[-1])
+        ifelse(var1 == var2, var12 <- paste0("I(", var1, "^2)"), var12 <- paste0(var2, 
+            ":", var1)[-1])
         
         # the first category is censored to avoid multicolinarity
         for (i in seq(var12)) {
             if (!var12[i] %in% unlist(dimnames(m@pp$X)[2])) 
                 var12[i] <- paste0(var1, ":", var2)[-1][i]
             if (!var12[i] %in% unlist(dimnames(m@pp$X)[2])) 
-                stop(paste("Model does not include the interaction of", var1, "and", var2, "."))
+                stop(paste("Model does not include the interaction of", 
+                  var1, "and", var2, "."))
         }
     } else {
-        ifelse(var1 == var2, var12 <- paste0("I(", var1, "^2)"), var12 <- paste0(var2, ":", var1))
+        ifelse(var1 == var2, var12 <- paste0("I(", var1, "^2)"), var12 <- paste0(var2, 
+            ":", var1))
         
         # the first category is censored to avoid multicolinarity
         for (i in seq(var12)) {
             if (!var12[i] %in% unlist(dimnames(m@pp$X)[2])) 
                 var12[i] <- paste0(var1, ":", var2)[i]
             if (!var12[i] %in% unlist(dimnames(m@pp$X)[2])) 
-                stop(paste("Model does not include the interaction of", var1, "and", var2, "."))
+                stop(paste("Model does not include the interaction of", 
+                  var1, "and", var2, "."))
         }
     }
     
@@ -97,26 +107,36 @@ interplot.lmerMod <- function(m, var1, var2, plot = TRUE, hist = FALSE, var2_dt
         if (is.na(xmax)) 
             xmax <- max(m@frame[var2], na.rm = T)
         
-        steps <- eval(parse(text = paste0("length(unique(na.omit(m@frame$", var2, ")))")))
+        if (is.null(steps)) {
+          steps <- eval(parse(text = paste0("length(unique(na.omit(m$model$", 
+                                            var2, ")))")))
+        }
+        
         if (steps > 100) 
             steps <- 100  # avoid redundant calculation
     }
     
-    coef <- data.frame(fake = seq(xmin, xmax, length.out = steps), coef1 = NA, ub = NA, lb = NA)
-    coef_df <- data.frame(fake = numeric(0), coef1 = numeric(0), ub = numeric(0), lb = numeric(0), 
-        model = character(0))
+    coef <- data.frame(fake = seq(xmin, xmax, length.out = steps), coef1 = NA, 
+        ub = NA, lb = NA)
+    coef_df <- data.frame(fake = numeric(0), coef1 = numeric(0), ub = numeric(0), 
+        lb = numeric(0), model = character(0))
     
     if (factor_v1) {
-        for (j in 1:(length(levels(eval(parse(text = paste0("m@frame$", var1_bk))))) - 1)) {
-            # only n - 1 interactions; one category is avoided against multicolinarity
+        for (j in 1:(length(levels(eval(parse(text = paste0("m@frame$", 
+            var1_bk))))) - 1)) {
+            # only n - 1 interactions; one category is avoided against
+            # multicolinarity
             
             for (i in 1:steps) {
-                coef$coef1[i] <- mean(m.sims@fixef[, match(var1[j + 1], unlist(dimnames(m@pp$X)[2]))] + 
-                  coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))])
-                coef$ub[i] <- quantile(m.sims@fixef[, match(var1[j + 1], unlist(dimnames(m@pp$X)[2]))] + 
-                  coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))], 0.975)
-                coef$lb[i] <- quantile(m.sims@fixef[, match(var1[j + 1], unlist(dimnames(m@pp$X)[2]))] + 
-                  coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))], 0.025)
+                coef$coef1[i] <- mean(m.sims@fixef[, match(var1[j + 1], 
+                  unlist(dimnames(m@pp$X)[2]))] + coef$fake[i] * m.sims@fixef[, 
+                  match(var12[j], unlist(dimnames(m@pp$X)[2]))])
+                coef$ub[i] <- quantile(m.sims@fixef[, match(var1[j + 1], 
+                  unlist(dimnames(m@pp$X)[2]))] + coef$fake[i] * m.sims@fixef[, 
+                  match(var12[j], unlist(dimnames(m@pp$X)[2]))], 0.975)
+                coef$lb[i] <- quantile(m.sims@fixef[, match(var1[j + 1], 
+                  unlist(dimnames(m@pp$X)[2]))] + coef$fake[i] * m.sims@fixef[, 
+                  match(var12[j], unlist(dimnames(m@pp$X)[2]))], 0.025)
             }
             
             if (plot == TRUE) {
@@ -135,19 +155,25 @@ interplot.lmerMod <- function(m, var1, var2, plot = TRUE, hist = FALSE, var2_dt
             }
         }
         coef_df$value <- as.factor(coef_df$value)
-        interplot.plot(m = coef_df, hist = hist, var2_dt = var2_dt, point = point, ercolor = ercolor, esize = esize, ralpha = ralpha, rfill = rfill, ...) + facet_grid(. ~ value)
+        interplot.plot(m = coef_df, hist = hist, var2_dt = var2_dt, point = point, 
+            ercolor = ercolor, esize = esize, ralpha = ralpha, rfill = rfill, 
+            ...) + facet_grid(. ~ value)
         
     } else if (factor_v2) {
-        for (j in 1:(length(levels(eval(parse(text = paste0("m@frame$", var2_bk))))) - 1)) {
-            # only n - 1 interactions; one category is avoided against multicolinarity
+        for (j in 1:(length(levels(eval(parse(text = paste0("m@frame$", 
+            var2_bk))))) - 1)) {
+            # only n - 1 interactions; one category is avoided against
+            # multicolinarity
             
             for (i in 1:steps) {
                 coef$coef1[i] <- mean(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + 
                   coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))])
                 coef$ub[i] <- quantile(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + 
-                  coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))], 0.975)
+                  coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))], 
+                  0.975)
                 coef$lb[i] <- quantile(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + 
-                  coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))], 0.025)
+                  coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))], 
+                  0.025)
             }
             
             if (plot == TRUE) {
@@ -166,7 +192,9 @@ interplot.lmerMod <- function(m, var1, var2, plot = TRUE, hist = FALSE, var2_dt
             }
         }
         coef_df$value <- as.factor(coef_df$value)
-        interplot.plot(m = coef_df, hist = hist, var2_dt = var2_dt, point = point, ercolor = ercolor, esize = esize, ralpha = ralpha, rfill = rfill, ...) + facet_grid(. ~ value)
+        interplot.plot(m = coef_df, hist = hist, var2_dt = var2_dt, point = point, 
+            ercolor = ercolor, esize = esize, ralpha = ralpha, rfill = rfill, 
+            ...) + facet_grid(. ~ value)
         
         
     } else {
@@ -175,12 +203,15 @@ interplot.lmerMod <- function(m, var1, var2, plot = TRUE, hist = FALSE, var2_dt
             2 else 1
         
         for (i in 1:steps) {
-            coef$coef1[i] <- mean(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + multiplier * 
-                coef$fake[i] * m.sims@fixef[, match(var12, unlist(dimnames(m@pp$X)[2]))])
-            coef$ub[i] <- quantile(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + multiplier * 
-                coef$fake[i] * m.sims@fixef[, match(var12, unlist(dimnames(m@pp$X)[2]))], 0.975)
-            coef$lb[i] <- quantile(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + multiplier * 
-                coef$fake[i] * m.sims@fixef[, match(var12, unlist(dimnames(m@pp$X)[2]))], 0.025)
+            coef$coef1[i] <- mean(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + 
+                multiplier * coef$fake[i] * m.sims@fixef[, match(var12, 
+                  unlist(dimnames(m@pp$X)[2]))])
+            coef$ub[i] <- quantile(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + 
+                multiplier * coef$fake[i] * m.sims@fixef[, match(var12, 
+                  unlist(dimnames(m@pp$X)[2]))], 0.975)
+            coef$lb[i] <- quantile(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + 
+                multiplier * coef$fake[i] * m.sims@fixef[, match(var12, 
+                  unlist(dimnames(m@pp$X)[2]))], 0.025)
         }
         
         if (plot == TRUE) {
@@ -191,7 +222,9 @@ interplot.lmerMod <- function(m, var1, var2, plot = TRUE, hist = FALSE, var2_dt
                   var2_dt <- var2_dt
                 }
             }
-          interplot.plot(m = coef, hist = hist, var2_dt = var2_dt, point = point, ercolor = ercolor, esize = esize, ralpha = ralpha, rfill = rfill, ...)
+            interplot.plot(m = coef, hist = hist, var2_dt = var2_dt, point = point, 
+                ercolor = ercolor, esize = esize, ralpha = ralpha, rfill = rfill, 
+                ...)
         } else {
             names(coef) <- c(var2, "coef", "ub", "lb")
             return(coef)
@@ -201,7 +234,9 @@ interplot.lmerMod <- function(m, var1, var2, plot = TRUE, hist = FALSE, var2_dt
 }
 
 #' @export
-interplot.glmerMod <- function(m, var1, var2, plot = TRUE, hist = FALSE, var2_dt = NA, point = FALSE, sims = 5000, xmin = NA, xmax = NA, ercolor = NA, esize = 0.5, ralpha = 0.5, rfill = "grey70", ...) {
+interplot.glmerMod <- function(m, var1, var2, plot = TRUE, steps = NULL, hist = FALSE, 
+    var2_dt = NA, point = FALSE, sims = 5000, xmin = NA, xmax = NA, ercolor = NA, 
+    esize = 0.5, ralpha = 0.5, rfill = "grey70", ...) {
     set.seed(324)
     
     m.class <- class(m)
@@ -216,39 +251,47 @@ interplot.glmerMod <- function(m, var1, var2, plot = TRUE, hist = FALSE, var2_dt
     
     if (is.factor(eval(parse(text = paste0("m@frame$", var1))))) {
         var1_bk <- var1
-        var1 <- paste0(var1, levels(eval(parse(text = paste0("m@frame$", var1)))))
+        var1 <- paste0(var1, levels(eval(parse(text = paste0("m@frame$", 
+            var1)))))
         factor_v1 <- TRUE
-        ifelse(var1 == var2, var12 <- paste0("I(", var1, "^2)"), var12 <- paste0(var2, ":", var1)[-1])
+        ifelse(var1 == var2, var12 <- paste0("I(", var1, "^2)"), var12 <- paste0(var2, 
+            ":", var1)[-1])
         
         # the first category is censored to avoid multicolinarity
         for (i in seq(var12)) {
             if (!var12[i] %in% unlist(dimnames(m@pp$X)[2])) 
                 var12[i] <- paste0(var1, ":", var2)[-1][i]
             if (!var12[i] %in% unlist(dimnames(m@pp$X)[2])) 
-                stop(paste("Model does not include the interaction of", var1, "and", var2, "."))
+                stop(paste("Model does not include the interaction of", 
+                  var1, "and", var2, "."))
         }
     } else if (is.factor(eval(parse(text = paste0("m@frame$", var2))))) {
         var2_bk <- var2
-        var2 <- paste0(var2, levels(eval(parse(text = paste0("m@frame$", var2)))))
+        var2 <- paste0(var2, levels(eval(parse(text = paste0("m@frame$", 
+            var2)))))
         factor_v2 <- TRUE
-        ifelse(var1 == var2, var12 <- paste0("I(", var1, "^2)"), var12 <- paste0(var2, ":", var1)[-1])
+        ifelse(var1 == var2, var12 <- paste0("I(", var1, "^2)"), var12 <- paste0(var2, 
+            ":", var1)[-1])
         
         # the first category is censored to avoid multicolinarity
         for (i in seq(var12)) {
             if (!var12[i] %in% unlist(dimnames(m@pp$X)[2])) 
                 var12[i] <- paste0(var1, ":", var2)[-1][i]
             if (!var12[i] %in% unlist(dimnames(m@pp$X)[2])) 
-                stop(paste("Model does not include the interaction of", var1, "and", var2, "."))
+                stop(paste("Model does not include the interaction of", 
+                  var1, "and", var2, "."))
         }
     } else {
-        ifelse(var1 == var2, var12 <- paste0("I(", var1, "^2)"), var12 <- paste0(var2, ":", var1))
+        ifelse(var1 == var2, var12 <- paste0("I(", var1, "^2)"), var12 <- paste0(var2, 
+            ":", var1))
         
         # the first category is censored to avoid multicolinarity
         for (i in seq(var12)) {
             if (!var12[i] %in% unlist(dimnames(m@pp$X)[2])) 
                 var12[i] <- paste0(var1, ":", var2)[i]
             if (!var12[i] %in% unlist(dimnames(m@pp$X)[2])) 
-                stop(paste("Model does not include the interaction of", var1, "and", var2, "."))
+                stop(paste("Model does not include the interaction of", 
+                  var1, "and", var2, "."))
         }
     }
     
@@ -264,26 +307,36 @@ interplot.glmerMod <- function(m, var1, var2, plot = TRUE, hist = FALSE, var2_dt
         if (is.na(xmax)) 
             xmax <- max(m@frame[var2], na.rm = T)
         
-        steps <- eval(parse(text = paste0("length(unique(na.omit(m@frame$", var2, ")))")))
+        if (is.null(steps)) {
+          steps <- eval(parse(text = paste0("length(unique(na.omit(m$model$", 
+                                            var2, ")))")))
+        }
+        
         if (steps > 100) 
             steps <- 100  # avoid redundant calculation
     }
     
-    coef <- data.frame(fake = seq(xmin, xmax, length.out = steps), coef1 = NA, ub = NA, lb = NA)
-    coef_df <- data.frame(fake = numeric(0), coef1 = numeric(0), ub = numeric(0), lb = numeric(0), 
-        model = character(0))
+    coef <- data.frame(fake = seq(xmin, xmax, length.out = steps), coef1 = NA, 
+        ub = NA, lb = NA)
+    coef_df <- data.frame(fake = numeric(0), coef1 = numeric(0), ub = numeric(0), 
+        lb = numeric(0), model = character(0))
     
     if (factor_v1) {
-        for (j in 1:(length(levels(eval(parse(text = paste0("m@frame$", var1_bk))))) - 1)) {
-            # only n - 1 interactions; one category is avoided against multicolinarity
+        for (j in 1:(length(levels(eval(parse(text = paste0("m@frame$", 
+            var1_bk))))) - 1)) {
+            # only n - 1 interactions; one category is avoided against
+            # multicolinarity
             
             for (i in 1:steps) {
-                coef$coef1[i] <- mean(m.sims@fixef[, match(var1[j + 1], unlist(dimnames(m@pp$X)[2]))] + 
-                  coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))])
-                coef$ub[i] <- quantile(m.sims@fixef[, match(var1[j + 1], unlist(dimnames(m@pp$X)[2]))] + 
-                  coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))], 0.975)
-                coef$lb[i] <- quantile(m.sims@fixef[, match(var1[j + 1], unlist(dimnames(m@pp$X)[2]))] + 
-                  coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))], 0.025)
+                coef$coef1[i] <- mean(m.sims@fixef[, match(var1[j + 1], 
+                  unlist(dimnames(m@pp$X)[2]))] + coef$fake[i] * m.sims@fixef[, 
+                  match(var12[j], unlist(dimnames(m@pp$X)[2]))])
+                coef$ub[i] <- quantile(m.sims@fixef[, match(var1[j + 1], 
+                  unlist(dimnames(m@pp$X)[2]))] + coef$fake[i] * m.sims@fixef[, 
+                  match(var12[j], unlist(dimnames(m@pp$X)[2]))], 0.975)
+                coef$lb[i] <- quantile(m.sims@fixef[, match(var1[j + 1], 
+                  unlist(dimnames(m@pp$X)[2]))] + coef$fake[i] * m.sims@fixef[, 
+                  match(var12[j], unlist(dimnames(m@pp$X)[2]))], 0.025)
             }
             
             if (plot == TRUE) {
@@ -302,19 +355,25 @@ interplot.glmerMod <- function(m, var1, var2, plot = TRUE, hist = FALSE, var2_dt
             }
         }
         coef_df$value <- as.factor(coef_df$value)
-        interplot.plot(m = coef_df, hist = hist, var2_dt = var2_dt, point = point, ercolor = ercolor, esize = esize, ralpha = ralpha, rfill = rfill, ...) + facet_grid(. ~ value)
+        interplot.plot(m = coef_df, hist = hist, steps = steps, var2_dt = var2_dt, point = point, 
+            ercolor = ercolor, esize = esize, ralpha = ralpha, rfill = rfill, 
+            ...) + facet_grid(. ~ value)
         
     } else if (factor_v2) {
-        for (j in 1:(length(levels(eval(parse(text = paste0("m@frame$", var2_bk))))) - 1)) {
-            # only n - 1 interactions; one category is avoided against multicolinarity
+        for (j in 1:(length(levels(eval(parse(text = paste0("m@frame$", 
+            var2_bk))))) - 1)) {
+            # only n - 1 interactions; one category is avoided against
+            # multicolinarity
             
             for (i in 1:steps) {
                 coef$coef1[i] <- mean(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + 
                   coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))])
                 coef$ub[i] <- quantile(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + 
-                  coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))], 0.975)
+                  coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))], 
+                  0.975)
                 coef$lb[i] <- quantile(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + 
-                  coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))], 0.025)
+                  coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))], 
+                  0.025)
             }
             
             if (plot == TRUE) {
@@ -333,7 +392,9 @@ interplot.glmerMod <- function(m, var1, var2, plot = TRUE, hist = FALSE, var2_dt
             }
         }
         coef_df$value <- as.factor(coef_df$value)
-        interplot.plot(m = coef_df, hist = hist, var2_dt = var2_dt, point = point, ercolor = ercolor, esize = esize, ralpha = ralpha, rfill = rfill, ...) + facet_grid(. ~ value)
+        interplot.plot(m = coef_df, steps = steps, hist = hist, var2_dt = var2_dt, point = point, 
+            ercolor = ercolor, esize = esize, ralpha = ralpha, rfill = rfill, 
+            ...) + facet_grid(. ~ value)
         
         
     } else {
@@ -342,12 +403,15 @@ interplot.glmerMod <- function(m, var1, var2, plot = TRUE, hist = FALSE, var2_dt
             2 else 1
         
         for (i in 1:steps) {
-            coef$coef1[i] <- mean(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + multiplier * 
-                coef$fake[i] * m.sims@fixef[, match(var12, unlist(dimnames(m@pp$X)[2]))])
-            coef$ub[i] <- quantile(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + multiplier * 
-                coef$fake[i] * m.sims@fixef[, match(var12, unlist(dimnames(m@pp$X)[2]))], 0.975)
-            coef$lb[i] <- quantile(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + multiplier * 
-                coef$fake[i] * m.sims@fixef[, match(var12, unlist(dimnames(m@pp$X)[2]))], 0.025)
+            coef$coef1[i] <- mean(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + 
+                multiplier * coef$fake[i] * m.sims@fixef[, match(var12, 
+                  unlist(dimnames(m@pp$X)[2]))])
+            coef$ub[i] <- quantile(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + 
+                multiplier * coef$fake[i] * m.sims@fixef[, match(var12, 
+                  unlist(dimnames(m@pp$X)[2]))], 0.975)
+            coef$lb[i] <- quantile(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + 
+                multiplier * coef$fake[i] * m.sims@fixef[, match(var12, 
+                  unlist(dimnames(m@pp$X)[2]))], 0.025)
         }
         
         if (plot == TRUE) {
@@ -358,11 +422,13 @@ interplot.glmerMod <- function(m, var1, var2, plot = TRUE, hist = FALSE, var2_dt
                   var2_dt <- var2_dt
                 }
             }
-          interplot.plot(m = coef, hist = hist, var2_dt = var2_dt, point = point, ercolor = ercolor, esize = esize, ralpha = ralpha, rfill = rfill, ...)
+            interplot.plot(m = coef, steps = steps, hist = hist, var2_dt = var2_dt, point = point, 
+                ercolor = ercolor, esize = esize, ralpha = ralpha, rfill = rfill, 
+                ...)
         } else {
             names(coef) <- c(var2, "coef", "ub", "lb")
             return(coef)
         }
         
     }
-} 
+}
